DATA TOOL BOX
=====================

This is a python tool box project for handling global datasets. It contains the following features:

1. Augumented pandas DataFrames adding meta data, 
2. Automatic unit conversion and table based computations
3. ID based data structure

Authors:
Andreas Geiges  
Gaurav Ganti

Dependencies
------------
- pandas
- gitpython
- openscm-units
- pint==0.9
- pycountry
- fuzzywuzzy
- tqdm

Installation via pip
--------------------


    pip install datatoolbox


Testing
----------

From the root directory, run:

    pytest

